@@ -5,15 +5,17 @@ import requests
 
 from wencaipy.common.wcParameter import (MAX_QUERY_SIZE, QUERY_TYPE,Question_Url,headers_wc,
                                          Drop_columns_ipo, Drop_columns_ipo_2, Fields_basic, Fields_query_etf, Fields_query_index)
-from wencaipy.utils.tradeDate import today, if_traded_now, get_real_trade_date
+from wencaipy.utils.tradeDate import today, if_traded_now, get_real_trade_date, get_last_tradedate
 from wencaipy.common.dataToExcel import data_to_excel
 from wencaipy.common.wcParameter import Fields_query_condbond
 
 
 def fetch_data_from_wencai(trade_date=None, fields_query=None,fields_out=None, query_type=None):
-    if not trade_date:
+    if (not trade_date) and (if_traded_now()):
         trade_date = today()
-    trade_date=get_real_trade_date(trade_date) 
+    else:
+        trade_date= get_last_tradedate() #get_real_trade_date(trade_date)
+    print(trade_date)
 
     if not fields_query:
         if query_type==QUERY_TYPE().fund:
@@ -90,6 +92,6 @@ if __name__ == "__main__":
     #print(fetch_data_from_wencai(query_type=QUERY_TYPE().fund))
     #print(fetch_data_from_wencai(query_type=QUERY_TYPE().index))
     #print(fetch_data_from_wencai(query_type=QUERY_TYPE().bond))
-    print(fetch_data_from_wencai(query_type=QUERY_TYPE().stock))
+    #print(fetch_data_from_wencai(query_type=QUERY_TYPE().stock))
     
     
